pplpy_doc: Python interface to the Parma Polyhedra Library (documentation)
==========================================================================

Description
-----------

PPL Python wrapper (documentation)

License
-------

GPL version 3


Upstream Contact
----------------

-  https://github.com/videlec/pplpy
